@@ -86,7 +86,7 @@
 #define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED
-#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54e00
+#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
 #endif
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x54e00
+#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x54f00
 #  endif
 #endif
 
